Documentation
¶
Overview ¶
Package gaeplatform - implementation for platform code for appengine
add timeout to test, example go test -timeout 60s
Index ¶
- func NewEmailSender() platform.SendMail
- func NewPersistedEmailStore() platform.PersistedEmailStore
- func NewPersistedPropertyList() platform.PersistedPropertyList
- func NewPersistedVersionedEvents() platform.PersistedVersionedEvents
- type Event
- type PersistedEmail
- type PersistedProperties
- type PersistedPropertyEvents
- Bugs
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewEmailSender ¶
NewEmailSender is the factory method to create an email sender
func NewPersistedEmailStore ¶
func NewPersistedEmailStore() platform.PersistedEmailStore
NewPersistedEmailStore is the factory method to create an email store
func NewPersistedPropertyList ¶
func NewPersistedPropertyList() platform.PersistedPropertyList
NewPersistedPropertyList is the factory method to create an property list store
func NewPersistedVersionedEvents ¶
func NewPersistedVersionedEvents() platform.PersistedVersionedEvents
NewPersistedVersionedEvents is the factory method to create a persisted events store
Types ¶
type Event ¶
type Event struct {
ID int
Value interface{}
}
Event is the []byte gob-encoded array of events
type PersistedEmail ¶
type PersistedEmail struct {
EmailID string `datastore:"EmailId"` // legacy name
Email string `datastore:"Email"` // legacy name
PropertyID string `datastore:"PropertyId"` // legacy name
}
PersistedEmail is the structure used to store an email address and other PII information
type PersistedProperties ¶
type PersistedProperties struct {
ParentKey string `datastore:"k,noindex"`
TransactionIndex int `datastore:"i"` // indexed in order to get the last one
}
PersistedProperties is the structure used to a property id record (the id is in the key)
type PersistedPropertyEvents ¶
type PersistedPropertyEvents struct {
Events []byte `datastore:"e,noindex"` // make sure smaller than 1MB (datastore limit)
First int `datastore:"f,noindex"`
Last int `datastore:"l,noindex"`
Compressed bool `datastore:"c,noindex"`
Type int `datastore:"t,noindex"`
}
PersistedPropertyEvents is the record that holds some property events
Notes ¶
Bugs ¶
change array items []PersistedEmail to array of pointers